@@ -1,9 +1,8 @@
 module SCCNonlinearSolveChainRulesCoreExt
 
-using SCCNonlinearSolve
-using SCCNonlinearSolve: SCCAlg, scc_solve_up
+import SCCNonlinearSolve: SCCAlg, scc_solve_up
 using SciMLBase: SCCNonlinearProblem, AbstractSensitivityAlgorithm, ChainRulesOriginator,
-    _concrete_solve_adjoint
+                 _concrete_solve_adjoint
 
 import ChainRulesCore
 
